<?php

namespace xenarabia\BestAnswer\XF\Pub\Controller;

use XF\Pub\Controller\AbstractController;
use XF\Mvc\ParameterBag;


class BestAnswer extends AbstractController{

    protected function preDispatchController($action, ParameterBag $params)
	{
		$this->assertRegistrationRequired();
	}


	protected function assertCanEditAnswer() {
        if(!\XF::visitor()->hasPermission('BestAnswersPermissions', 'canEditAnswer') 
            || !\XF::visitor()->hasPermission('BestAnswersAdminPermissio', 'canEditOtherAnswers') ) {
			throw $this->exception($this->noPermission());
		}		
	}

    public function actionAdd(ParameterBag $params)
	{
        $post_id = $params['post_id'];
        $posts = \XF::finder('XF:Post')->where('post_id', $post_id)->fetchOne();
        $thread_id = $posts->thread_id;
       
        $threads = \XF::finder('XF:Thread')->where('thread_id', $thread_id)->fetchOne();
        
        $user = \XF::finder('XF:User')->where('user_id', $posts->user_id)->fetchOne();
        
       
        $extra = array(
            'title'	=> $threads->title,
            'prefix_id' => $threads->prefix_id,
            'link' => \XF::app()->router('public')->buildLink('threads/post',$threads,['post_id'=>$post_id])
        );

        /** @var \XF\Repository\UserAlert $alertRepo */
        $alertRepo = \XF::app()->repository('XF:UserAlert');
        $alertRepo->alert($user , $threads->user_id, $threads->username, 'user', $user->user_id, 'bestanswer',$extra);

        // close thread and add prefix 
        $threads->xena_post_ba = $post_id;
        $threads->xena_userid_ba = $posts->user_id;
        if( \XF::options()->ba_close_thread == 1){
            $threads->discussion_open = false;
            $threads->prefix_id = \XF::options()->ba_prefix['action'];
        }

        $threads->last_post_date = time();

        $threads->save();

        // sending email to post user 
        if(\XF::options()->ba_umail == 1)
        {
            $mail = \XF::app()->mailer()->newMail();
            $mail->setToUser($user);
            $mail->setTemplate('ba_bestanswer_email', [
                'threads' => $threads,
                'user' => $user
            ]);
        
            $mail->queue();
        }
        

        
        return $this->redirect($this->buildLink('threads',$threads));
    }
    


	public function actionDelete(ParameterBag $params)
	{
		$this->assertCanEditAnswer();
		$posts = $this->finder('XF:Post')->where('post_id', $params['post_id'])->fetchOne();
		$viewParams = [
			'contentUrl' => '#',
			'confirmUrl' => $this->buildLink('bestanswer/dodelete', $params),
			'contentTitle' => substr($posts->message,0,300)
		];	
		return $this->view('xenarabia\BestAnswer\XF:ActionConfirm','ba_action_confirm', $viewParams);
    }
    

    public function actionDoDelete(ParameterBag $params)
	{
        $posts = $this->finder('XF:Post')->where('post_id', $params['post_id'])->fetchOne();
       
        $threads = \XF::finder('XF:Thread')->where('thread_id', $posts->thread_id)->fetchOne();
        $threads->prefix_id = 0;
        $threads->xena_post_ba = 0;
        $threads->xena_userid_ba = 0;
        $threads->discussion_open = true;
        $threads->save();
        return $this->redirect($this->buildLink('threads',$threads));
	}
    
    public function actionViewprofile(ParameterBag $params)
	{
        $user_id = $params['user_id'];
        $db = \XF::db();
        $bestAnswersThread = $db->fetchRow("SELECT * FROM xf_thread WHERE xena_userid_ba = $user_id");
        $threadxena_post_ba = $bestAnswersThread['xena_post_ba'];
        $bestAnswersPost = $db->fetchRow("SELECT * FROM xf_post WHERE post_id = $threadxena_post_ba");
        $baPost = \XF::finder('XF:Post')->where('post_id', $threadxena_post_ba)->fetch();
        $baThread =  \XF::finder('XF:Thread')->where('xena_userid_ba', $user_id)->fetch();
        $viewParams = [
			'ba_post' => $baPost,
			'ba_thread' => $baThread
		];
		return $this->view('xenarabia\BestAnswer\XF:BestAnswersProfile', 'ba_bestanswers_profile', $viewParams);
    }

	protected function assertBAExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XF:Thread', $id, $with, $phraseKey);
	}

}